Marius Vollmer <[EMAIL PROTECTED]> writes:

> Also, I already have a small UI improvement suggestion: what about
> always showing the boot menu, not only when you hit the MENU key?  I
> tend to miss the window where the key needs to be pressed all the
> time.  Maybe the menu could be shown when the root device is "ask"?

Here is a small patch to implement this.

--- bootmenu.sh 2006-08-13 10:50:06.000000000 +0300
+++ bootmenu-ask.sh     2006-08-21 18:17:30.000000000 +0300
@@ -110,8 +110,8 @@
     i=$((i+1))
 done
 
-#show onscreeen menu if menu key was pressed
-if [ "$HWKEYSTATE" = "$KEY_MENU" ] ; then
+#show onscreeen menu if menu key was pressed or when the root device is "ask"
+if [ "$HWKEYSTATE" = "$KEY_MENU" -o "$default_root" = "ask" ] ; then
        menu_init
        menu_redraw
        menu_loop
_______________________________________________
maemo-developers mailing list
maemo-developers@maemo.org
https://maemo.org/mailman/listinfo/maemo-developers

Reply via email to